@@ -2,13 +2,13 @@
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ConverseConfig {
     /// *Required* Specifies how to process the subsequent incoming audio.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub audio_in_config: ::core::option::Option<AudioInConfig>,
     /// *Required* Specifies how to format the audio that will be returned.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub audio_out_config: ::core::option::Option<AudioOutConfig>,
     /// *Required* Represents the current dialog state.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub converse_state: ::core::option::Option<ConverseState>,
 }
 /// Specifies how to process the `audio_in` data that will be provided in
@@ -18,14 +18,14 @@ pub struct ConverseConfig {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AudioInConfig {
     /// *Required* Encoding of audio data sent in all `audio_in` messages.
-    #[prost(enumeration = "audio_in_config::Encoding", tag = "1")]
+    #[prost(enumeration="audio_in_config::Encoding", tag="1")]
     pub encoding: i32,
     /// *Required* Sample rate (in Hertz) of the audio data sent in all `audio_in`
     /// messages. Valid values are from 16000-24000, but 16000 is optimal.
     /// For best results, set the sampling rate of the audio source to 16000 Hz.
     /// If that's not possible, use the native sample rate of the audio source
     /// (instead of re-sampling).
-    #[prost(int32, tag = "2")]
+    #[prost(int32, tag="2")]
     pub sample_rate_hertz: i32,
 }
 /// Nested message and enum types in `AudioInConfig`.
@@ -56,15 +56,15 @@ pub mod audio_in_config {
 pub struct AudioOutConfig {
     /// *Required* The encoding of audio data to be returned in all `audio_out`
     /// messages.
-    #[prost(enumeration = "audio_out_config::Encoding", tag = "1")]
+    #[prost(enumeration="audio_out_config::Encoding", tag="1")]
     pub encoding: i32,
     /// *Required* The sample rate in Hertz of the audio data returned in
     /// `audio_out` messages. Valid values are: 16000-24000.
-    #[prost(int32, tag = "2")]
+    #[prost(int32, tag="2")]
     pub sample_rate_hertz: i32,
     /// *Required* Current volume setting of the device's audio output.
     /// Valid values are 1 to 100 (corresponding to 1% to 100%).
-    #[prost(int32, tag = "3")]
+    #[prost(int32, tag="3")]
     pub volume_percentage: i32,
 }
 /// Nested message and enum types in `AudioOutConfig`.
@@ -95,7 +95,7 @@ pub struct ConverseState {
     /// `ConverseResponse`. If there was a prior `ConverseResponse`, do not omit
     /// this field; doing so will end that conversation (and this new request will
     /// start a new conversation).
-    #[prost(bytes = "bytes", tag = "1")]
+    #[prost(bytes="bytes", tag="1")]
     pub conversation_state: ::prost::bytes::Bytes,
 }
 /// The audio containing the assistant's response to the query. Sequential chunks
@@ -105,29 +105,29 @@ pub struct AudioOut {
     /// *Output-only* The audio data containing the assistant's response to the
     /// query. Sequential chunks of audio data are received in sequential
     /// `ConverseResponse` messages.
-    #[prost(bytes = "bytes", tag = "1")]
+    #[prost(bytes="bytes", tag="1")]
     pub audio_data: ::prost::bytes::Bytes,
 }
 /// The semantic result for the user's spoken query.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ConverseResult {
     /// *Output-only* The recognized transcript of what the user said.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub spoken_request_text: ::prost::alloc::string::String,
     /// *Output-only* The text of the assistant's spoken response. This is only
     /// returned for an IFTTT action.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub spoken_response_text: ::prost::alloc::string::String,
     /// *Output-only* State information for subsequent `ConverseRequest`. This
     /// value should be saved in the client and returned in the
     /// `conversation_state` with the next `ConverseRequest`. (The client does not
     /// need to interpret or otherwise use this value.) There is no need to save
     /// this information across device restarts.
-    #[prost(bytes = "bytes", tag = "3")]
+    #[prost(bytes="bytes", tag="3")]
     pub conversation_state: ::prost::bytes::Bytes,
     /// *Output-only* Specifies the mode of the microphone after this `Converse`
     /// RPC is processed.
-    #[prost(enumeration = "converse_result::MicrophoneMode", tag = "4")]
+    #[prost(enumeration="converse_result::MicrophoneMode", tag="4")]
     pub microphone_mode: i32,
     /// *Output-only* Updated volume level. The value will be 0 or omitted
     /// (indicating no change) unless a voice command such as "Increase the volume"
@@ -138,7 +138,7 @@ pub struct ConverseResult {
     /// supply it in the `AudioOutConfig` of the next `ConverseRequest`. (Some
     /// clients may also implement other ways to allow the current volume level to
     /// be changed, for example, by providing a knob that the user can turn.)
-    #[prost(int32, tag = "5")]
+    #[prost(int32, tag="5")]
     pub volume_percentage: i32,
 }
 /// Nested message and enum types in `ConverseResult`.
@@ -166,7 +166,7 @@ pub mod converse_result {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ConverseRequest {
     /// Exactly one of these fields must be specified in each `ConverseRequest`.
-    #[prost(oneof = "converse_request::ConverseRequest", tags = "1, 2")]
+    #[prost(oneof="converse_request::ConverseRequest", tags="1, 2")]
     pub converse_request: ::core::option::Option<converse_request::ConverseRequest>,
 }
 /// Nested message and enum types in `ConverseRequest`.
@@ -177,7 +177,7 @@ pub mod converse_request {
         /// The `config` message provides information to the recognizer that
         /// specifies how to process the request.
         /// The first `ConverseRequest` message must contain a `config` message.
-        #[prost(message, tag = "1")]
+        #[prost(message, tag="1")]
         Config(super::ConverseConfig),
         /// The audio data to be recognized. Sequential chunks of audio data are sent
         /// in sequential `ConverseRequest` messages. The first `ConverseRequest`
@@ -187,7 +187,7 @@ pub mod converse_request {
         /// Audio must be sent at approximately real-time (16000 samples per second).
         /// An error will be returned if audio is sent significantly faster or
         /// slower.
-        #[prost(bytes, tag = "2")]
+        #[prost(bytes, tag="2")]
         AudioIn(::prost::bytes::Bytes),
     }
 }
@@ -196,7 +196,7 @@ pub mod converse_request {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ConverseResponse {
     /// Exactly one of these fields will be populated in each `ConverseResponse`.
-    #[prost(oneof = "converse_response::ConverseResponse", tags = "1, 2, 3, 5")]
+    #[prost(oneof="converse_response::ConverseResponse", tags="1, 2, 3, 5")]
     pub converse_response: ::core::option::Option<converse_response::ConverseResponse>,
 }
 /// Nested message and enum types in `ConverseResponse`.
@@ -222,24 +222,24 @@ pub mod converse_response {
         /// message that specifies the error for the operation. If an error occurs
         /// during processing, this message will be set and there will be no further
         /// messages sent.
-        #[prost(message, tag = "1")]
+        #[prost(message, tag="1")]
         Error(super::super::super::super::rpc::Status),
         /// *Output-only* Indicates the type of event.
-        #[prost(enumeration = "EventType", tag = "2")]
+        #[prost(enumeration="EventType", tag="2")]
         EventType(i32),
         /// *Output-only* The audio containing the assistant's response to the query.
-        #[prost(message, tag = "3")]
+        #[prost(message, tag="3")]
         AudioOut(super::AudioOut),
         /// *Output-only* The semantic result for the user's spoken query.
-        #[prost(message, tag = "5")]
+        #[prost(message, tag="5")]
         Result(super::ConverseResult),
     }
 }
-#[doc = r" Generated client implementations."]
+/// Generated client implementations.
 pub mod embedded_assistant_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " Service that implements Google Assistant API."]
+    /// Service that implements Google Assistant API.
     #[derive(Debug, Clone)]
     pub struct EmbeddedAssistantClient<T> {
         inner: tonic::client::Grpc<T>,
@@ -247,8 +247,8 @@ pub mod embedded_assistant_client {
     impl<T> EmbeddedAssistantClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -267,83 +267,89 @@ pub mod embedded_assistant_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             EmbeddedAssistantClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Initiates or continues a conversation with the embedded assistant service."]
-        #[doc = " Each call performs one round-trip, sending an audio request to the service"]
-        #[doc = " and receiving the audio response. Uses bidirectional streaming to receive"]
-        #[doc = " results, such as the `END_OF_UTTERANCE` event, while sending audio."]
-        #[doc = ""]
-        #[doc = " A conversation is one or more gRPC connections, each consisting of several"]
-        #[doc = " streamed requests and responses."]
-        #[doc = " For example, the user says *Add to my shopping list* and the assistant"]
-        #[doc = " responds *What do you want to add?*. The sequence of streamed requests and"]
-        #[doc = " responses in the first gRPC message could be:"]
-        #[doc = ""]
-        #[doc = " *   ConverseRequest.config"]
-        #[doc = " *   ConverseRequest.audio_in"]
-        #[doc = " *   ConverseRequest.audio_in"]
-        #[doc = " *   ConverseRequest.audio_in"]
-        #[doc = " *   ConverseRequest.audio_in"]
-        #[doc = " *   ConverseResponse.event_type.END_OF_UTTERANCE"]
-        #[doc = " *   ConverseResponse.result.microphone_mode.DIALOG_FOLLOW_ON"]
-        #[doc = " *   ConverseResponse.audio_out"]
-        #[doc = " *   ConverseResponse.audio_out"]
-        #[doc = " *   ConverseResponse.audio_out"]
-        #[doc = ""]
-        #[doc = " The user then says *bagels* and the assistant responds"]
-        #[doc = " *OK, I've added bagels to your shopping list*. This is sent as another gRPC"]
-        #[doc = " connection call to the `Converse` method, again with streamed requests and"]
-        #[doc = " responses, such as:"]
-        #[doc = ""]
-        #[doc = " *   ConverseRequest.config"]
-        #[doc = " *   ConverseRequest.audio_in"]
-        #[doc = " *   ConverseRequest.audio_in"]
-        #[doc = " *   ConverseRequest.audio_in"]
-        #[doc = " *   ConverseResponse.event_type.END_OF_UTTERANCE"]
-        #[doc = " *   ConverseResponse.result.microphone_mode.CLOSE_MICROPHONE"]
-        #[doc = " *   ConverseResponse.audio_out"]
-        #[doc = " *   ConverseResponse.audio_out"]
-        #[doc = " *   ConverseResponse.audio_out"]
-        #[doc = " *   ConverseResponse.audio_out"]
-        #[doc = ""]
-        #[doc = " Although the precise order of responses is not guaranteed, sequential"]
-        #[doc = " ConverseResponse.audio_out messages will always contain sequential portions"]
-        #[doc = " of audio."]
+        /// Initiates or continues a conversation with the embedded assistant service.
+        /// Each call performs one round-trip, sending an audio request to the service
+        /// and receiving the audio response. Uses bidirectional streaming to receive
+        /// results, such as the `END_OF_UTTERANCE` event, while sending audio.
+        ///
+        /// A conversation is one or more gRPC connections, each consisting of several
+        /// streamed requests and responses.
+        /// For example, the user says *Add to my shopping list* and the assistant
+        /// responds *What do you want to add?*. The sequence of streamed requests and
+        /// responses in the first gRPC message could be:
+        ///
+        /// *   ConverseRequest.config
+        /// *   ConverseRequest.audio_in
+        /// *   ConverseRequest.audio_in
+        /// *   ConverseRequest.audio_in
+        /// *   ConverseRequest.audio_in
+        /// *   ConverseResponse.event_type.END_OF_UTTERANCE
+        /// *   ConverseResponse.result.microphone_mode.DIALOG_FOLLOW_ON
+        /// *   ConverseResponse.audio_out
+        /// *   ConverseResponse.audio_out
+        /// *   ConverseResponse.audio_out
+        ///
+        /// The user then says *bagels* and the assistant responds
+        /// *OK, I've added bagels to your shopping list*. This is sent as another gRPC
+        /// connection call to the `Converse` method, again with streamed requests and
+        /// responses, such as:
+        ///
+        /// *   ConverseRequest.config
+        /// *   ConverseRequest.audio_in
+        /// *   ConverseRequest.audio_in
+        /// *   ConverseRequest.audio_in
+        /// *   ConverseResponse.event_type.END_OF_UTTERANCE
+        /// *   ConverseResponse.result.microphone_mode.CLOSE_MICROPHONE
+        /// *   ConverseResponse.audio_out
+        /// *   ConverseResponse.audio_out
+        /// *   ConverseResponse.audio_out
+        /// *   ConverseResponse.audio_out
+        ///
+        /// Although the precise order of responses is not guaranteed, sequential
+        /// ConverseResponse.audio_out messages will always contain sequential portions
+        /// of audio.
         pub async fn converse(
             &mut self,
             request: impl tonic::IntoStreamingRequest<Message = super::ConverseRequest>,
-        ) -> Result<tonic::Response<tonic::codec::Streaming<super::ConverseResponse>>, tonic::Status>
-        {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+        ) -> Result<
+                tonic::Response<tonic::codec::Streaming<super::ConverseResponse>>,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.assistant.embedded.v1alpha1.EmbeddedAssistant/Converse",
             );
-            self.inner
-                .streaming(request.into_streaming_request(), path, codec)
-                .await
+            self.inner.streaming(request.into_streaming_request(), path, codec).await
         }
     }
 }
